@@ -1,6 +1,4 @@
-from .session import Session, SessionStorage
 from .template import Loader, append_template_suffix
-from .database import Connection
 
 import codex.tornado.helpers
 import tornado.websocket
@@ -11,12 +9,16 @@ import tornado.web
 import http.client
 import functools
 import traceback
+import importlib
 import sys
 import os
 
 class Application(tornado.web.Application):
-    def __init__(self, handlers=None, constants=None, **settings):
-        self.constants = constants
+
+    def __init__(self, handlers, app_settings):
+
+        settings = app_settings.config
+
         for arg_value in sys.argv:
             if arg_value.find('--port=') == 0:
                 self.port = arg_value.replace('--port=', '', 1).strip()
@@ -72,17 +74,7 @@ class Application(tornado.web.Application):
         
     def run(self):
         self.listen(self.port)
-        tornado.ioloop.IOLoop.instance().start()
-
-    def load_database(self):
-        if not Connection.engine:
-            if 'database' in self.settings and isinstance(self.settings['database'], dict):
-                if 'debug' in self.settings['database']:
-                    Connection.set_debug(self.settings['database']['debug'])
-                Connection.set_engine(self.settings['database'])
-            else:
-                return None
-        return Connection.create()
+        self.get_ioloop_instance().start()
 
 class ViewData(object):
     def __init__(self):
@@ -127,47 +119,15 @@ class Controller(tornado.web.RequestHandler):
         self.view = ViewData()
         self.request = request
         self.application = application
-        self._models = {}
 
         if not hasattr(self, 'uri'):
             self.uri = URI(self.request.path)
-
-        db_settings = self.application.settings.get('database')
-        if db_settings and 'auto_init' in db_settings and db_settings['auto_init']:
-            self.load_database()
-
-        if with_session:
-            sess_settings = self.application.settings.get('session')
-            if sess_settings and 'auto_init' in sess_settings and sess_settings['auto_init']:
-                self.load_session()
         
     def disable_cache(self):
         self.set_header('Cache-Control', 'no-cache, no-store, must-revalidate')
         self.set_header('Pragma', 'no-cache')
         self.set_header('Expires', '0')
 
-    def load_database(self):
-        if not hasattr(self, 'db'):
-            self.db = self.application.load_database()
-
-    def load_session(self):
-        if hasattr(self, 'session'):
-            return
-
-        config = self.settings.get('session')
-        if isinstance(config, dict) and config:
-
-            if 'cookie_name' not in config or not config['cookie_name']:
-                raise tornado.web.HTTPError(500, 'Cookie name for Session support must be defined')
-
-            if not SessionStorage.engine:
-                SessionStorage.set_engine(config)
-
-            # if not SessionStorage.gc_activated:
-            #     SessionStorage.set_gc(self.application.get_ioloop_instance(), 1000 * 3600)
-
-            self.session = Session(self, config)
-
     def write_error(self, status_code, **kwargs):
         kwargs['code'] = status_code
         if 'exc_info' in kwargs:
@@ -214,10 +174,6 @@ class Controller(tornado.web.RequestHandler):
                     values[k] = tornado.escape.xhtml_escape(v)
         return values
 
-    @property
-    def constants(self):
-        return self.application.constants
-
     @property
     def root_dir(self):
         return self.application.root_dir
@@ -229,65 +185,11 @@ class Controller(tornado.web.RequestHandler):
         template_name = append_template_suffix(template_name, self.settings.get('template_suffix'))
         view_data = self.view.all()
         view_data.update(kwargs)
-        view_data['constants'] = self.constants
         view_data['settings'] = self.settings
         if hasattr(self, 'uri'):
             view_data['uri'] = self.uri
         return super().render_string(template_name, **view_data)
 
-    def load_form(self, name, formdata_fields=None, **kwargs):
-        pos = name.rfind('.')
-        package = '.' + name.lower()
-
-        form = None
-        try:
-            form = getattr(__import__('app.forms' + package, fromlist=[name]), name)
-        except ImportError:
-            raise tornado.web.HTTPError(500, 'Form app.forms' + package + '.' + name + ' not found')
-        except AttributeError:
-            raise tornado.web.HTTPError(500, name + ' form not found in app.forms' + package)
-        if form is None:
-            return None
-
-        xss_filter = None if 'xss_filter' not in kwargs else kwargs['xss_filter']
-        if xss_filter is None:
-            xss_filter = self.settings.get('global_xss_filtering')
-        include_xss = [] if 'include_xss' not in kwargs else kwargs['include_xss']
-        exclude_xss = [] if 'exclude_xss' not in kwargs else kwargs['exclude_xss']
-        if formdata_fields is None:
-            formdata_fields = self.request.arguments.keys()
-
-        formdata = {}
-        for field in formdata_fields:
-            if (xss_filter and field not in exclude_xss) or (not xss_filter and field in include_xss):
-                formdata[field] = self.get_argument(field, xss_filter=True)
-            else:
-                formdata[field] = self.get_argument(field, xss_filter=False)
-
-        return form(self, formdata, **kwargs)
-
-    def load_model(self, name):
-        if not hasattr(self, 'db'):
-            raise tornado.web.HTTPError(500, 'Database must be loaded first')
-
-        loaded_model = self._models.get(name)
-        if not loaded_model:
-
-            package = '.' + name.lower()
-
-            try:
-                loaded_model = getattr(__import__('app.models' + package, fromlist=[name]), name)
-            except ImportError:
-                raise tornado.web.HTTPError(500, 'Model app.models' + package + '.' + name + ' not found')
-            except AttributeError:
-                raise tornado.web.HTTPError(500, name + ' model not found in app.models' + package)
-
-            if loaded_model:
-                loaded_model = loaded_model(self.db)
-                self._models[name] = loaded_model
-
-        return loaded_model
-
     def flash_cookie(self, name):
         value = self.get_cookie(name)
         if value is not None:
@@ -299,18 +201,9 @@ class Controller(tornado.web.RequestHandler):
         if value is not None:
             self.clear_cookie(name)
         return value
-    
-    def dispose_resources(self):
-        if hasattr(self, 'db'):
-            self.db.close()
-            del self.db
-        if hasattr(self, 'session'):
-            self.session.save()
-            del self.session
 
     def finish(self, chunk=None):
         super().finish(chunk)
-        self.dispose_resources()
 
     def get_unauthenticated_url(self):
         return self.settings.get('unauthenticated_url')
