@@ -39,9 +39,15 @@ class RequestForm(Form):
         self._delimiter_end = end
 
     def validation_errors(self):
-        errors = []
-        for field_id in self.errors.keys():
-            field = self._fields[field_id]
-            for e in self.errors[field_id]:
-                errors.append(e.replace('{{field_label}}', field.label.text))
-        return self._delimiter_start + (self._delimiter_end + self._delimiter_start).join(errors) + self._delimiter_end
\ No newline at end of file
+        error_string = ''
+        for e in self.errors.values():
+            error_string += (self._delimiter_start + (self._delimiter_end + self._delimiter_start).join(e) + self._delimiter_end)
+        return error_string
+
+    @property
+    def errors(self):
+        if self._errors is None:
+            for field_id in super().errors.keys():
+                for k, v in enumerate(self._errors[field_id]):
+                    self._errors[field_id][k] = v.replace('{{field_label}}', self._fields[field_id].label.text)
+        return self._errors
\ No newline at end of file
